import setuptools

setuptools.setup(
    name="tanishi",
    packages = ['tanishi'], 
    version="0.0.5",
    author="Himanshu",
    description="First python package",
    #long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)

